# Examples of NelderMeadSampler

## 1. File Structure

### example.py
### example_parallel.py
### example_enqueue.py
### example_sub_sampler.py

- This code demonstrates the general usage of NelderMeadSampler.
- For more information, please refer to the following documents : docs/source/user_guide/hpo

### coco

- This directory contains code for verifying NelderMeadSampler using the black-box optimization evaluation framework coco.
- For details, please refer to the README.md in the relevant directory.

## 2. Instructions

- After installing aiaccel and activating the virtual environment, run the corresponding file.

```bash
python example.py
```

## 3. Checking Results

- The execution results of the example code are displayed in the standard output.
